.. scikit-clarans documentation master file, created by
   sphinx-quickstart on Sat Jan 17 12:05:36 2026.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

scikit-clarans Documentation
============================

Welcome to the documentation for **scikit-clarans**, a specialized clustering library for Python.

**scikit-clarans** brings the power of the CLARANS (Clustering Large Applications based on RANdomized Search) algorithm to the **scikit-learn** ecosystem. It is designed to be:

*   **Efficient**: Optimized for larger datasets where standard k-medoids might struggle.
*   **Compatible**: A drop-in replacement for scikit-learn clusterers efficiently implementing `fit`, `predict`, and more.
*   **Flexible**: Supports customizable initialization strategies and distance metrics.

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   installation
   usage
   examples

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   api

.. toctree::
   :maxdepth: 3
   :caption: Gallery

   gallery/2d_clustering
   gallery/comparison
   gallery/quality_vs_k
   gallery/performance

.. toctree::
   :maxdepth: 3
   :caption: Project

   project
   contributing
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`

